clj-jargon.item-ops


cancelclj


continueclj


copyclj

(copy cm source dest)

copy-streamclj

(copy-stream cm
             istream
             user
             dest-path
             &
             {:keys [set-owner?] :or {set-owner? true}})

data-transfer-objclj

(data-transfer-obj {ao-factory :accessObjectFactory
                    irods-account :irodsAccount})

deleteclj

(delete cm a-path)
(delete cm a-path force?)

igetclj

(iget cm remote-path local-path tcl)
(iget cm remote-path local-path tcl control-block)

Transfers remote-path to local-path, using tcl as the TransferStatusCallbackListener

Transfers remote-path to local-path, using tcl as the TransferStatusCallbackListener
raw docstring

input-streamclj

(input-stream {file-factory :fileFactory :as cm} input-path)

Returns a FileInputStream for a file in iRODS pointed to by 'input-path'

Returns a FileInputStream for a file in iRODS pointed to by 'input-path'
raw docstring

iputclj

(iput cm local-path remote-path tcl)

Transfers local-path to remote-path, using tcl as the TransferStatusCallbackListener. tcl can also be set to nil.

Transfers local-path to remote-path, using tcl as the TransferStatusCallbackListener.
tcl can also be set to nil.
raw docstring

mkdirclj

(mkdir {cm-ao :fileSystemAO :as cm} dir-path)

mkdirsclj

(mkdirs {cm-ao :fileSystemAO :as cm} dir-path)

moveclj

(move cm
      source
      dest
      &
      {:keys [admin-users user skip-source-perms? update-fn]
       :or {admin-users #{} skip-source-perms? false update-fn (fn [_ _])}})

Moves a file/dir from source path 'source' into destination directory 'dest'.

Parameters: source - String containing the path to the file/dir being moved. dest - String containing the path to the destination directory. Should not end with a slash. :admin-users (optional) - List of users that must retain ownership on the file/dir being moved. :user (optional) - The username of the user performing the move. :skip-source-perms? (optional) - Boolean the tells move to skip ensuring that permissions for the admin users are correct. :update-fn (optional) - function of two arguments (the source path and an action (keyword))) to call to update the caller on the progress of the move

Moves a file/dir from source path 'source' into destination directory 'dest'.

Parameters:
  source - String containing the path to the file/dir being moved.
  dest - String containing the path to the destination directory. Should not end with a slash.
  :admin-users (optional) - List of users that must retain ownership on the file/dir being moved.
  :user (optional) - The username of the user performing the move.
  :skip-source-perms? (optional) - Boolean the tells move to skip ensuring that permissions for
                                   the admin users are correct.
  :update-fn (optional) - function of two arguments (the source path and an action (keyword)))
                          to call to update the caller on the progress of the move
raw docstring

move-allclj

(move-all cm
          sources
          dest
          &
          {:keys [admin-users user update-fn]
           :or {admin-users #{} update-fn (fn [_ _])}})

no-for-allclj


no-this-fileclj


output-streamclj

(output-stream {file-factory :fileFactory :as cm} output-path)

Returns an FileOutputStream for a file in iRODS pointed to by 'output-path'. If the file exists, it will be truncated.

Returns an FileOutputStream for a file in iRODS pointed to by 'output-path'. If the file exists,
it will be truncated.
raw docstring

read-fileclj

(read-file {file-factory :fileFactory :as cm} fpath buffer)

skipclj


tcbclj


transfer-callback-listenerclj

(transfer-callback-listener overall-status-callback-fn
                            status-callback-fn
                            transfer-asks-fn)

Returns an instance of TransferStatusCallbackListener with the overallStatusCallback(), statusCallback(), and transferAsksWhetherToForceOperation() functions delegated to the functions passed in.

Returns an instance of TransferStatusCallbackListener with the overallStatusCallback(),
statusCallback(), and transferAsksWhetherToForceOperation() functions delegated to the
functions passed in.
raw docstring

yes-for-allclj


yes-this-fileclj

cljdoc builds & hosts documentation for Clojure/Script libraries