clj-jargon.lazy-listings


count-list-entriesclj

(count-list-entries cm user dir-path)

Returns the number of entries in a directory listing. Useful for paging.

Returns the number of entries in a directory listing. Useful for paging.
raw docstring

list-collections-under-pathclj

(list-collections-under-path cm user dir-path)

Lists all of the collections under a path.

Lists all of the collections under a path.
raw docstring

list-files-inclj

(list-files-in {lister :lister} dir-path)

Returns a lazy listing of the files in the directory at the given path.

Returns a lazy listing of the files in the directory at the given path.
raw docstring

list-subdirs-inclj

(list-subdirs-in {lister :lister} dir-path)

Returns a lazy listing of the subdirectories in the directory at the given path.

Returns a lazy listing of the subdirectories in the directory at the given path.
raw docstring

num-collections-under-pathclj

(num-collections-under-path cm user dir-path)

The number of collections directly under the specified path. In other words, it's not recursive.

The number of collections directly under the specified path. In other words, 
it's not recursive.
raw docstring

num-dataobjects-under-pathclj

(num-dataobjects-under-path cm user dir-path)

The number of collections directly under the specified path. In other words, it's not recursive.

The number of collections directly under the specified path. In other words, 
it's not recursive.
raw docstring

paged-list-entriesclj

(paged-list-entries cm user dir-path sort-col sort-order limit offset)

Returns a paged directory listing.

Returns a paged directory listing.
raw docstring

user-collection-permsclj

(user-collection-perms cm collection)

Lists the users and their permissions that have access to a collection.

Lists the users and their permissions that have access to a collection.
raw docstring

user-dataobject-permsclj

(user-dataobject-perms cm dataobject-path)

Lists the user and their permissions that have access to a dataobject.

Lists the user and their permissions that have access to a dataobject.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries