clj-jargon.metadata


add-avucljmultimethod


add-metadataclj

(add-metadata cm
              dir-path
              attr
              value
              unit
              &
              {:keys [known-type] :or {known-type nil}})

attr-value?clj

(attr-value? metadata attr val)
(attr-value? cm path attr val & {:keys [known-type] :or {known-type nil}})

Returns a truthy value if path has metadata that has an attribute of attr and a value of val.

Returns a truthy value if path has metadata that has an attribute of attr and
a value of val.
raw docstring

attribute?clj

(attribute? cm dir-path attr & {:keys [known-type] :or {known-type nil}})

Returns true if the path has the associated attribute.

Returns true if the path has the associated attribute.
raw docstring

delete-avucljmultimethod


delete-avusclj

(delete-avus cm dir-path avu-maps & {:keys [known-type] :or {known-type nil}})

delete-metadataclj

(delete-metadata cm dir-path attr)
(delete-metadata cm dir-path attr val)

get-attributeclj

(get-attribute {data-ao :dataObjectAO collection-ao :collectionAO :as cm}
               dir-path
               attr
               &
               {:keys [known-type] :or {known-type nil}})

Returns a list of avu maps for a specific attribute associated with dir-path

Returns a list of avu maps for a specific attribute associated with dir-path
raw docstring

get-attribute-valueclj

(get-attribute-value {data-ao :dataObjectAO collection-ao :collectionAO :as cm}
                     apath
                     attr
                     val
                     &
                     {:keys [known-type] :or {known-type nil}})

get-avus-by-collectionclj

(get-avus-by-collection {collection-ao :collectionAO} file-path attr units)

Returns AVUs associated with a collection that have the given attribute and value.

Returns AVUs associated with a collection that have the given attribute and value.
raw docstring

get-metadataclj

(get-metadata {data-ao :dataObjectAO collection-ao :collectionAO :as cm}
              path
              &
              {:keys [known-type] :or {known-type nil}})

Returns all of the metadata associated with a path.

Returns all of the metadata associated with a path.
raw docstring

list-collections-in-tree-with-attrclj

Lists the paths to directories in a subtree given the path to the root of the subtree and an AVU specification. The AVU specification is a map in the following format:

{:name  "name"
 :value "value"
 :unit  "unit"}

The values in the map are strings indicating the name, value or unit of the AVUs to match. Each entry in the map is optional, so that the caller can search for any combination of name and value. For example, to search for AVUs named 'foo', the AVU specification would simply be {:name "foo"}. Unrecognized keys in the AVU specification are currently ignored and conditions are not added for null values.

The path is the absolute path to the root of the subtree to search. Items that are not in this directory or any of its descendants will not be matched. The root of the subtree is included in the search.

Lists the paths to directories in a subtree given the path to the root of the subtree and an
AVU specification. The AVU specification is a map in the following format:

    {:name  "name"
     :value "value"
     :unit  "unit"}

The values in the map are strings indicating the name, value or unit of the AVUs to match. Each
entry in the map is optional, so that the caller can search for any combination of name and
value. For example, to search for AVUs named 'foo', the AVU specification would simply be
{:name "foo"}. Unrecognized keys in the AVU specification are currently ignored and conditions
are not added for null values.

The path is the absolute path to the root of the subtree to search. Items that are not in this
directory or any of its descendants will not be matched. The root of the subtree is included
in the search.
raw docstring

list-collections-with-attr-unitsclj

(list-collections-with-attr-units {collection-ao :collectionAO} attr units)

list-collections-with-attr-valueclj

(list-collections-with-attr-value {collection-ao :collectionAO} attr value)

list-everything-in-tree-with-attrclj

(list-everything-in-tree-with-attr cm path avu-spec)

Lists the paths to both files and directories in a subtree given the path to the root of the subtree and an AVU specification. The AVU specification is a map in the following format:

{:name  "name"
 :value "value"
 :unit  "unit"}

The values in the map are strings indicating the name, value or unit of the AVUs to match. Each entry in the map is optional, so that the caller can search for any combination of name and value. For example, to search for AVUs named 'foo', the AVU specification would simply be {:name "foo"}. Unrecognized keys in the AVU specification are currently ignored and conditions are not added for null values.

The path is the absolute path to the root of the subtree to search. Items that are not in this directory or any of its descendants will not be matched. The root of the subtree is included in the search.

Lists the paths to both files and directories in a subtree given the path to the root of the
subtree and an AVU specification. The AVU specification is a map in the following format:

    {:name  "name"
     :value "value"
     :unit  "unit"}

The values in the map are strings indicating the name, value or unit of the AVUs to match. Each
entry in the map is optional, so that the caller can search for any combination of name and
value. For example, to search for AVUs named 'foo', the AVU specification would simply be
{:name "foo"}. Unrecognized keys in the AVU specification are currently ignored and conditions
are not added for null values.

The path is the absolute path to the root of the subtree to search. Items that are not in this
directory or any of its descendants will not be matched. The root of the subtree is included
in the search.
raw docstring

list-everything-with-attr-valueclj

(list-everything-with-attr-value cm attr value)

Generates a sequence of all collections and data objects with a given attribute having a given value.

Parameters: cm - the connected jargon context attr - the name of the attribute value - the value of the attribute

Returns: It returns a sequence of collections and data object paths.

Generates a sequence of all collections and data objects with a given attribute having a given
value.

Parameters:
  cm    - the connected jargon context
  attr  - the name of the attribute
  value - the value of the attribute

Returns:
  It returns a sequence of collections and data object paths.
raw docstring

list-files-in-tree-with-attrclj

Lists the paths to files in a subtree given the path to the root of the subtree and an AVU specification. The AVU specification is a map in the following format:

{:name  "name"
 :value "value"
 :unit  "unit"}

The values in the map are strings indicating the name, value or unit of the AVUs to match. Each entry in the map is optional, so that the caller can search for any combination of name and value. For example, to search for AVUs named 'foo', the AVU specification would simply be {:name "foo"}. Unrecognized keys in the AVU specification are currently ignored and conditions are not added for null values.

The path is the absolute path to the root of the subtree to search. Items that are not in this directory or any of its descendants will not be matched. The root of the subtree is included in the search.

Lists the paths to files in a subtree given the path to the root of the subtree and an AVU
specification. The AVU specification is a map in the following format:

    {:name  "name"
     :value "value"
     :unit  "unit"}

The values in the map are strings indicating the name, value or unit of the AVUs to match. Each
entry in the map is optional, so that the caller can search for any combination of name and
value. For example, to search for AVUs named 'foo', the AVU specification would simply be
{:name "foo"}. Unrecognized keys in the AVU specification are currently ignored and conditions
are not added for null values.

The path is the absolute path to the root of the subtree to search. Items that are not in this
directory or any of its descendants will not be matched. The root of the subtree is included
in the search.
raw docstring

list-files-with-attrclj

(list-files-with-attr {executor :executor} attr)

list-files-with-avuclj

(list-files-with-avu {executor :executor} n op value)

map2avuclj

(map2avu avu-map)

Converts an avu map into an AvuData instance.

Converts an avu map into an AvuData instance.
raw docstring

max-gen-query-resultsclj


modify-avucljmultimethod


set-metadataclj

(set-metadata cm
              dir-path
              attr
              value
              unit
              &
              {:keys [known-type] :or {known-type nil}})

Sets an avu for dir-path.

Sets an avu for dir-path.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries