clj-jargon.permissions


collection-perm-mapclj

(collection-perm-map cm user coll-path)

Uses (user-collection-perms) to grab the 'raw' permissions for the user for the collection at coll-path and returns a map with the keys :read, :write, and :own. The values are booleans.

Uses (user-collection-perms) to grab the 'raw' permissions for
the user for the collection at coll-path and returns a map with
the keys :read, :write, and :own. The values are booleans.
raw docstring

collection-perms-rsclj

(collection-perms-rs cm user coll-path)

contains-accessible-obj?clj

(contains-accessible-obj? cm user dpath)

dataobject-perm-mapclj

(dataobject-perm-map cm user data-path)

Uses (user-dataobject-perms) to grab the 'raw' permissions for the user for the dataobject at data-path, and returns a map with the keys :read :write and :own. The values are booleans.

Uses (user-dataobject-perms) to grab the 'raw' permissions for
the user for the dataobject at data-path, and returns a map with
the keys :read :write and :own. The values are booleans.
raw docstring

dataobject-perms-rsclj

(dataobject-perms-rs cm user-id data-path)

fix-ownersclj

(fix-owners cm abs-path & owners)

fix-permsclj

(fix-perms cm src dst user admin-users skip-source-perms?)

fmt-permcljmultimethod

Translates a jargonesque permission to a keyword permission.

Parameter: jargon-perm - the jargon permission

Returns: The keyword representation, :own, :write, :read or nil.

Translates a jargonesque permission to a keyword permission.

Parameter:
  jargon-perm - the jargon permission

Returns:
  The keyword representation, :own, :write, :read or nil.
raw docstring

inherit-permsclj

(inherit-perms cm path user admin-users)

is-readable?clj

(is-readable? cm user path & {:keys [known-type] :or {known-type nil}})

Returns true if 'user' can read 'path'.

Parameters: cm - The iRODS context map user - String containing a username. path - String containing an path for something in iRODS.

Returns true if 'user' can read 'path'.

Parameters:
  cm - The iRODS context map
  user - String containing a username.
  path - String containing an path for something in iRODS.
raw docstring

is-writeable?clj

(is-writeable? cm user path & {:keys [known-type] :or {known-type nil}})

Returns true if 'user' can write to 'path'.

Parameters: cm - The iRODS context map user - String containign a username. path - String containing an absolute path for something in iRODS.

Returns true if 'user' can write to 'path'.

Parameters:
  cm - The iRODS context map
  user - String containign a username.
  path - String containing an absolute path for something in iRODS.
raw docstring

list-pathsclj

(list-paths {cm-ao :fileSystemAO :as cm} parent-path & flags)

Returns a list of paths for the entries under the parent path. This is not recursive .

Parameters: cm - The context map parent-path - The path of the parrent collection (directory). :ignore-child-exns - When this flag is provided, child names that are too long will not cause an exception to be thrown. If they are not ignored, an exception will be thrown, causing no paths to be listed. An ignored child will be replaced with a nil in the returned list.

Returns: It returns a list path names for the entries under the parent.

Throws: FileNotFoundException - This is thrown if parent-path is not in iRODS. See validate-path-lengths for path-related exceptions.

Returns a list of paths for the entries under the parent path.  This is not
recursive .

Parameters:
  cm - The context map
  parent-path - The path of the parrent collection (directory).
  :ignore-child-exns - When this flag is provided, child names that are too
    long will not cause an exception to be thrown.  If they are not ignored,
    an exception will be thrown, causing no paths to be listed.  An ignored
    child will be replaced with a nil in the returned list.

Returns:
  It returns a list path names for the entries under the parent.

Throws:
  FileNotFoundException - This is thrown if parent-path is not in iRODS.
  See validate-path-lengths for path-related exceptions.
raw docstring

list-user-permclj

(list-user-perm cm abs-path & {:keys [known-type] :or {known-type nil}})

list-user-permsclj

(list-user-perms cm abs-path & {:keys [known-type] :or {known-type nil}})

make-file-accessibleclj

(make-file-accessible cm path user admin-users)

Ensures that a file is accessible to all users that have access to the file.

Ensures that a file is accessible to all users that have access to the file.
raw docstring

none-permclj


one-user-to-rule-them-all?clj

(one-user-to-rule-them-all? {lister :lister :as cm} user)

own-permclj


owns?clj

(owns? cm user fpath & {:keys [known-type] :or {known-type nil}})

paths-writeable?clj

(paths-writeable? cm user paths)

Returns true if all of the paths in 'paths' are writeable by 'user'.

Parameters: cm - The iRODS context map user - A string containing the username of the user requesting the check. paths - A sequence of strings containing the paths to be checked.

Returns true if all of the paths in 'paths' are writeable by 'user'.

Parameters:
  cm - The iRODS context map
  user - A string containing the username of the user requesting the check.
  paths - A sequence of strings containing the paths to be checked.
raw docstring

perm-mapclj

(perm-map [perm-id username])

perm-map-forclj

(perm-map-for perms-code)

perm-order-mapclj


perm-user->mapclj

(perm-user->map [perm-id username])

permission-forclj

(permission-for cm user fpath & {:keys [known-type] :or {known-type nil}})

Determines a given user's permission for a given collection or data object.

Parameters: cm - The context for an open connection to iRODS. user - the user name fpath - the logical path of the collection or data object.

Returns: It returns the aggregated permission.

Determines a given user's permission for a given collection or data object.

Parameters:
  cm - The context for an open connection to iRODS.
  user - the user name
  fpath - the logical path of the collection or data object.

Returns:
  It returns the aggregated permission.
raw docstring

permissionsclj

(permissions cm user fpath & {:keys [known-type] :or {known-type nil}})

permissions-inherited?clj

(permissions-inherited? {collection-ao :collectionAO :as cm} path)

Determines whether the inheritance attribute of a collection is true.

Parameters: cm - The iRODS context map path - The path being checked.

Determines whether the inheritance attribute of a collection is true.

Parameters:
  cm - The iRODS context map
  path - The path being checked.
raw docstring

process-parent-dirsclj

(process-parent-dirs f process? path)

process-permsclj

(process-perms f cm path user admin-users)

Fetches the permissions on path, remove anything relating to admin users or user or the context-map user, then map f over the permissions

Fetches the permissions on `path`, remove anything relating to admin users
or `user` or the context-map user, then map `f` over the permissions
raw docstring

read-permclj


remove-access-permissionsclj

(remove-access-permissions cm user abs-path)

Remove permissions, non-recursively where applicable

Remove permissions, non-recursively where applicable
raw docstring

remove-inheritsclj

(remove-inherits {collection-ao :collectionAO zone :zone :as cm} path)

Sets the inheritance attribute of a collection to false (recursively).

Parameters: cm - The iRODS context map path - the path being altered.

Sets the inheritance attribute of a collection to false (recursively).

Parameters:
  cm - The iRODS context map
  path - the path being altered.
raw docstring

remove-obsolete-permsclj

(remove-obsolete-perms cm path user admin-users)

Removes permissions that are no longer required for a directory that isn't shared. Read permissions are no longer required for any user who no longer has access to any file or subdirectory.

Removes permissions that are no longer required for a directory that isn't shared.  Read
permissions are no longer required for any user who no longer has access to any file or
subdirectory.
raw docstring

remove-permissionsclj

(remove-permissions cm user fpath)

Remove permissions, recursively where applicable

Remove permissions, recursively where applicable
raw docstring

removed-ownersclj

(removed-owners curr-user-perms set-of-new-owners)

reset-permsclj

(reset-perms cm path user admin-users)

set-coll-permsclj

(set-coll-perms {coll :collectionAO zone :zone :as cm}
                user
                fpath
                read?
                write?
                own?
                recursive?)

set-dataobj-permsclj

(set-dataobj-perms {dataobj :dataObjectAO zone :zone :as cm}
                   user
                   fpath
                   read?
                   write?
                   own?)

set-inheritsclj

(set-inherits {collection-ao :collectionAO zone :zone :as cm} path)

Sets the inheritance attribute of a collection to true (recursively).

Parameters: cm - The iRODS context map path - The path being altered.

Sets the inheritance attribute of a collection to true (recursively).

Parameters:
  cm - The iRODS context map
  path - The path being altered.
raw docstring

set-ownerclj

(set-owner {data-ao :dataObjectAO collection-ao :collectionAO zone :zone :as cm}
           path
           owner
           &
           {:keys [known-type] :or {known-type nil}})

Sets the owner of 'path' to the username 'owner'.

Parameters: cm - The iRODS context map path - The path whose owner is being set. owner - The username of the user who will be the owner of 'path'.

Sets the owner of 'path' to the username 'owner'.

Parameters:
  cm - The iRODS context map
  path - The path whose owner is being set.
  owner - The username of the user who will be the owner of 'path'.
raw docstring

set-permissionclj

(set-permission cm user fpath permission)
(set-permission cm user fpath permission recursive?)

set-permissionsclj

(set-permissions cm user fpath read? write? own?)
(set-permissions cm user fpath read? write? own? recursive?)

set-readableclj

(set-readable cm username readable? path)

str->perm-constclj

(str->perm-const s)

write-permclj

cljdoc builds & hosts documentation for Clojure/Script libraries