(define-specific-queries cm queries)Defines the specific queries in a map indexed by query alias.
Defines the specific queries in a map indexed by query alias.
(delete-specific-queries cm queries)Deletes the queries in a map indexed by query alias.
Deletes the queries in a map indexed by query alias.
(execute-specific-query cm alias page-size & args)(get-specific-query-results cm alias & args)(paged-query cm alias limit offset & args)(query-specifically cm query-ao query-inst limit)(specific-query? cm alias)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |