clj-jargon.tickets


create-ticketclj

(create-ticket cm user fpath ticket-id & {:keys [rw-mode] :as ticket-opts})

delete-ticketclj

(delete-ticket cm user ticket-id)

Deletes the ticket specified by ticket-id.

Deletes the ticket specified by ticket-id.
raw docstring

igetclj

(iget cm ticket-id remote-path local-path tcl)
(iget cm ticket-id remote-path local-path tcl control-block)

Transfers remote-path to local-path using a ticket, using tcl as the TransferStatusCallbackListener

Transfers remote-path to local-path using a ticket, using tcl as the TransferStatusCallbackListener
raw docstring

iputclj

(iput cm ticket-id local-path remote-path tcl)
(iput cm ticket-id local-path remote-path tcl control-block)

Transfers local-path to remote-path using a ticket, using tcl as the TransferStatusCallbackListener. tcl can also be set to nil.

Transfers local-path to remote-path using a ticket, using tcl as the TransferStatusCallbackListener.
tcl can also be set to nil.
raw docstring

modify-ticketclj

(modify-ticket cm user ticket-id & {:as ticket-opts})

public-ticket?clj

(public-ticket? cm user ticket-id)

Checks to see if the provided ticket ID is publicly accessible.

Checks to see if the provided ticket ID is publicly accessible.
raw docstring

publicize-ticketclj

(publicize-ticket cm ticket-id)

Allows the ticket to be viewed by the public group.

Allows the ticket to be viewed by the public group.
raw docstring

set-ticket-optionsclj

(set-ticket-options ticket-id
                    tas
                    {:keys [byte-write-limit expiry file-write-limit
                            uses-limit]})

Sets the optional settings for a ticket, such as the expiration date and the uses limit.

Sets the optional settings for a ticket, such as the expiration date
and the uses limit.
raw docstring

ticket-by-idclj

(ticket-by-id cm user ticket-id)

Looks up the ticket by the provided ticket-id string and returns an instance of Ticket.

Looks up the ticket by the provided ticket-id string and
returns an instance of Ticket.
raw docstring

ticket-expired?clj

(ticket-expired? ticket-obj)

ticket-ids-for-pathclj

(ticket-ids-for-path cm user path)

ticket-input-streamclj

(ticket-input-stream cm user ticket-id)

ticket-mapclj

(ticket-map cm user ticket-id)

ticket-obj->mapclj

(ticket-obj->map ticket)

ticket-proxy-input-streamclj

(ticket-proxy-input-stream cm user ticket-id)

ticket-used-up?clj

(ticket-used-up? ticket-obj)

ticket?clj

(ticket? cm user ticket-id)

Checks to see if ticket-id is already being used as a ticket identifier.

Checks to see if ticket-id is already being used as a ticket
identifier.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries